﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.SignalR;
using Microsoft.EntityFrameworkCore;
using VCinemaApi.Models;
using VCinemaApi.Repositories;

namespace VCinemaApi.Hubs
{
    public class VCinemaHub : Hub<IVCinemaHub>
    {
        private readonly IScreenRepository _screenRepository;
        private readonly IWatcherRepository _watcherRepository;

        public VCinemaHub(IScreenRepository screenRepository, IWatcherRepository watcherRepository)
        {
            _screenRepository = screenRepository;
            _watcherRepository = watcherRepository;
        }

        public override async Task OnConnectedAsync()
        {
            await _watcherRepository.CreateWatcher(Context.ConnectionId);
            await base.OnConnectedAsync();
        }

        public override async Task OnDisconnectedAsync(Exception exception)
        {
            await _watcherRepository.DeleteWatcher(Context.ConnectionId);
            await base.OnDisconnectedAsync(exception);
        }

        public async Task<IEnumerable<Screen>> GetScreens()
        {
            return await _screenRepository.GetScreens();
        }

        public async Task<Screen> GetScreenById(int screenId)
        {
            return await _screenRepository.GetScreenById(screenId);
        }
    }
}
